#
# steering, Programme/schedule management for AURA
#
# Copyright (C) 2011-2017, 2020, Ernesto Rico Schmidt
# Copyright (C) 2017-2019, Ingo Leindecker
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
# details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

from drf_spectacular.views import SpectacularAPIView, SpectacularSwaggerView
from rest_framework import routers

from django.conf import settings
from django.conf.urls.static import static
from django.contrib import admin
from django.urls import include, path
from program.views import (
    APIApplicationStateView,
    APICategoryViewSet,
    APIEpisodeViewSet,
    APIFundingCategoryViewSet,
    APIImageViewSet,
    APILanguageViewSet,
    APILicenseViewSet,
    APILinkTypeViewSet,
    APIMediaViewSet,
    APIMusicFocusViewSet,
    APIProfileViewSet,
    APIProgramBasicViewSet,
    APIProgramCalendarViewSet,
    APIProgramPlayoutViewSet,
    APIRadioSettingsViewSet,
    APIRRuleViewSet,
    APIScheduleViewSet,
    APIShowViewSet,
    APITimeSlotViewSet,
    APITopicViewSet,
    APITypeViewSet,
    APIUserViewSet,
)

admin.autodiscover()

router = routers.DefaultRouter()
router.register(r"users", APIUserViewSet, basename="user")
router.register(r"profiles", APIProfileViewSet, basename="profile")
router.register(r"shows", APIShowViewSet, basename="show")
router.register(r"schedules", APIScheduleViewSet, basename="schedule")
router.register(r"timeslots", APITimeSlotViewSet, basename="timeslot")
router.register(r"episodes", APIEpisodeViewSet, basename="episode")
router.register(r"categories", APICategoryViewSet, basename="category")
router.register(r"topics", APITopicViewSet, basename="topic")
router.register(r"types", APITypeViewSet, basename="type")
router.register(r"music-focus", APIMusicFocusViewSet, basename="music-focus")
router.register(r"funding-categories", APIFundingCategoryViewSet, basename="funding-category")
router.register(r"languages", APILanguageViewSet, basename="language")
router.register(r"licenses", APILicenseViewSet, basename="license")
router.register(r"link-types", APILinkTypeViewSet, basename="link-type")
router.register(r"rrules", APIRRuleViewSet, basename="rrule")
router.register(r"images", APIImageViewSet, basename="image")
router.register(r"settings", APIRadioSettingsViewSet, basename="settings")
router.register(r"program/basic", APIProgramBasicViewSet, basename="program-basic")
router.register(r"program/playout", APIProgramPlayoutViewSet, basename="program-playout")
router.register(r"program/calendar", APIProgramCalendarViewSet, basename="program-calendar")
router.register(r"media", APIMediaViewSet, basename="media")

urlpatterns = [
    path("openid/", include("oidc_provider.urls", namespace="oidc_provider")),
    path("api/v1/", include(router.urls)),
    path("api/v1/schema/", SpectacularAPIView.as_view(), name="schema"),
    path(
        "api/v1/schema/swagger-ui/",
        SpectacularSwaggerView.as_view(url_name="schema"),
        name="swagger-ui",
    ),
    path("admin/", admin.site.urls),
] + static(settings.STATIC_URL, document_root=settings.STATIC_ROOT)

if settings.DEBUG or settings.OPERATION_MODE == "tests":
    # This endpoint is only usable with OPERATION_MODE == "tests"
    # but we include it in DEBUG mode so that developers can inspect the schema.
    urlpatterns.append(
        path("api/v1/debug/application-state/", APIApplicationStateView.as_view()),
    )
